/*
 * Licensed to JumpMind Inc under one or more contributor 
 * license agreements.  See the NOTICE file distributed
 * with this work for additional information regarding 
 * copyright ownership.  JumpMind Inc licenses this file
 * to you under the GNU Lesser General Public License (the
 * "License"); you may not use this file except in compliance
 * with the License. 
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see           
 * <http://www.gnu.org/licenses/>.
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License. 
 */


package org.jumpmind.symmetric.service;

import java.math.BigDecimal;
import java.util.Date;
import java.util.Map;

import org.jumpmind.symmetric.config.IParameterFilter;

/**
 * Get and set application wide configuration information.
 *
 * 
 */
public interface IParameterService {

    public static final String ALL = "ALL";

    public BigDecimal getDecimal(String key);
    
    public BigDecimal getDecimal(String key, BigDecimal defaulVal);

    public boolean is(String key);
    
    public boolean is(String key, boolean defaultVal);

    public int getInt(String key);
    
    public int getInt(String key, int defaultVal);

    public long getLong(String key);
    
    public long getLong(String key, long defaultVal);

    public String getString(String key);
    
    public String getString(String key, String defaultVal);

    public void saveParameter(String key, Object paramValue);

    public void saveParameter(String nodeId, String nodeGroupId, String key, Object paramValue);

    public void saveParameters(String nodeId, String nodeGroupId, Map<String, Object> parameters);

    public void rereadParameters();

    public Date getLastTimeParameterWereCached();

    public Map<String, String> getAllParameters();

    public void setParameterFilter(IParameterFilter f);

    /**
     * Get the group id for this instance
     */
    public String getNodeGroupId();

    /**
     * Get the external id for this instance
     */
    public String getExternalId();

    /**
     * Provide the url used to register at to get initial configuration
     * information
     */
    public String getRegistrationUrl();

    /**
     * Provide information about the URL used to contact this symmetric instance
     */
    public String getSyncUrl();

}